![LUSID_by_Finbourne](./resources/Finbourne_Logo_Teal.svg)

# Python tools for LUSID

This package contains a set of utility functions for interacting with [LUSID by FINBOURNE](https://www.finbourne.com/lusid-technology). To use it you'll need a LUSID account. [Sign up for free at lusid.com](https://www.lusid.com/app/signup)


![PyPI](https://img.shields.io/pypi/v/finbourne_sdk_utils?color=blue)

For more details see the lusid-python-tools [wiki](https://github.com/finbourne/lusid-python-tools/wiki).

## Installation

The PyPi package for lusid-python-tools can installed globally on your machine using the following command:

```sh
$ pip install finbourne-sdk-utils
```

or if you are running as a non privileged user you may prefer to install specifically for your user account:

```sh
$ pip install --user finbourne-sdk-utils
```

## Upgrading

To upgrade finbourne_sdk_utils run one of the commands below 

```sh
$ pip install finbourne-sdk-utils -U
```

or

```sh
$ pip install finbourne-sdk-utils -U --user
```
